==> cylc_7.6.1.orig.tar.xz: cylc-7.6.1/README.md <==
# The Cylc Workflow Engine

[![Build Status](https://travis-ci.org/cylc/cylc.svg?branch=master)](https://travis-ci.org/cylc/cylc)
[![DOI](https://zenodo.org/badge/1836229.svg)](https://zenodo.org/badge/latestdoi/1836229)

Cylc (“silk”) orchestrates complex distributed suites of interdependent cycling
tasks. It was originally designed for environmental forecasting systems at
[NIWA](https://www.niwa.co.nz).

### Copyright and Terms of Use

Copyright (C) 2008-2018 NIWA
 
Cylc is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.
 
Cylc is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License along with
cylc.  If not, see [GNU licenses](http://www.gnu.org/licenses/).

## Cylc Documentation
 * See [The Cylc Home Page](https://cylc.github.io/cylc)

## Code Contributors
<!--  git shortlog -s -n -->
 *  Hilary Oliver
 *  Matt Shin
 *  Ben Fitzpatrick
 *  Andrew Clark
 *  Oliver Sanders
 *  Luis Kornblueh
 *  Kerry Day
 *  David Matthews
 *  Tim Whitcomb
 *  Scott Wales
 *  Annette Osprey
 *  Bruno Kinoshita
 *  Domingo Manubens Gil
 *  Jonny Williams
 *  Alex Reinecke
 *  Chan Wilson
 *  Kevin Pulo
 
## Acknowledgement For Non-Cylc Work:
Licences for non-cylc work included in this distribution can be found in the
`licences/` directory.
 * `lib/cherrypy/`:
    External software library released under a BSD license.
    Minor modification to ignore an import warning.
    See [cherrypy](http://www.cherrypy.org/).
 * `lib/isodatetime/`:
    Unmodified external software library released under the LGPL license.
    See [metomi/isodatetime](https://github.com/metomi/isodatetime/).
 * `lib/jinja2/`:
    External software library released under a BSD license.
    See [Jinja2](http://jinja.pocoo.org/).
 * `lib/markupsafe/`:
    External software library released under a BSD license, used by Jinja2.
    See [MarkupSafe](http://www.pocoo.org/projects/markupsafe/).
 * `lib/xdot.py`:
    External software released under the LGPL license.
    Modifications based on version 0.6. See
    [xdot](https://github.com/jrfonseca/xdot.py)

==> cylc_7.7.2.orig.tar.xz: cylc-7.7.2/README.md <==
# The Cylc Workflow Engine

[![Build Status](https://travis-ci.org/cylc/cylc.svg?branch=master)](https://travis-ci.org/cylc/cylc)
[![DOI](https://zenodo.org/badge/1836229.svg)](https://zenodo.org/badge/latestdoi/1836229)

Cylc (“silk”) orchestrates complex distributed suites of interdependent cycling
tasks. It was originally designed for environmental forecasting systems at
[NIWA](https://www.niwa.co.nz).

### Copyright and Terms of Use

Copyright (C) 2008-2018 NIWA
 
Cylc is free software: you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.
 
Cylc is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License along with
cylc.  If not, see [GNU licenses](http://www.gnu.org/licenses/).

## Cylc Documentation
 * See [The Cylc Web Site](https://cylc.github.io/cylc)

## Code Contributors
<!--  git shortlog -s -n -->
 *  Hilary Oliver
 *  Matt Shin
 *  Ben Fitzpatrick
 *  Andrew Clark
 *  Oliver Sanders
 *  Declan Valters
 *  Sadie Bartholomew
 *  Luis Kornblueh
 *  Kerry Day
 *  Prasanna Challuri
 *  David Matthews
 *  Tim Whitcomb
 *  Scott Wales
 *  Tomek Trzeciak
 *  Thomas Coleman
 *  Bruno Kinoshita
 *  Annette Osprey
 *  Jonathan Thomas
 *  Rosalyn Hatcher
 *  Domingo Manubens Gil
 *  Jonny Williams
 *  Milton Woods
 *  Alex Reinecke
 *  Chan Wilson
 *  Kevin Pulo
 *  Lois Hugget
 *  Martin Dix
 
## Acknowledgement For Non-Cylc Work:
Licences for non-cylc work included in this distribution can be found in the
`licences/` directory.
 * `lib/cherrypy/`:
    External software library released under a BSD license.
    Minor modification to ignore an import warning.
    See [cherrypy](http://www.cherrypy.org/).
 * `lib/isodatetime/`:
    Unmodified external software library released under the LGPL license.
    See [metomi/isodatetime](https://github.com/metomi/isodatetime/).
 * `lib/jinja2/`:
    External software library released under a BSD license.
    See [Jinja2](http://jinja.pocoo.org/).
 * `lib/markupsafe/`:
    External software library released under a BSD license, used by Jinja2.
    See [MarkupSafe](http://www.pocoo.org/projects/markupsafe/).
 * `lib/xdot.py`:
    External software released under the LGPL license.
    Modifications based on version 0.6. See
    [xdot](https://github.com/jrfonseca/xdot.py)
